"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cloud_functions_1 = require("../methods/cloud-functions");
const fixtures_1 = require("./fixtures");
describe('cloud functions', () => {
    it('should forward requests', async () => {
        const handler = jest.fn();
        const send = jest.fn();
        const payload = fixtures_1.createPubSubRequest('forward me');
        const fun = cloud_functions_1.createPubSubCloudFunctions(handler);
        await fun({ body: payload }, { status: () => ({ send }) });
        expect(handler).toHaveBeenCalledWith({
            message: payload.message,
            data: 'forward me',
            context: JSON.parse(JSON.stringify(payload)),
        });
    });
    it('should run onError when thrown', async () => {
        const payload = fixtures_1.createPubSubRequest('forward me');
        const handle = () => {
            throw new Error('error');
        };
        const onError = jest.fn();
        const send = jest.fn();
        const fun = await cloud_functions_1.createPubSubCloudFunctions(handle, { onError });
        await fun({ body: payload }, { status: () => ({ send }) });
        expect(onError).toHaveBeenCalledWith(new Error('error'));
    });
    it('should throw when onError is undefined', async () => {
        const payload = fixtures_1.createPubSubRequest('forward me');
        const handle = () => {
            throw new Error('error');
        };
        const send = jest.fn();
        const fun = await cloud_functions_1.createPubSubCloudFunctions(handle);
        await fun({ body: payload }, { status: () => ({ send }) }).catch(e => expect(e.message).toBe('error'));
    });
});
//# sourceMappingURL=cloud-functions.test.js.map