"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.pubSubFastifyPlugin = void 0;
const fastify_plugin_1 = __importDefault(require("fastify-plugin"));
const common_1 = require("../common");
const types_1 = require("../types");
const pubSubFastifyPluginAsync = async (fastify, options) => {
    const { path = '/', handler, parseJson, onError } = options;
    fastify.post(path, {
        schema: {
            body: types_1.PubSubRequest,
            response: { 204: {} },
        },
    }, async (req, reply) => {
        try {
            const res = await common_1.handlePubSubMessage({
                message: req.body.message,
                handler,
                parseJson,
                context: req,
            });
            reply.code((res && res.statusCode) || 204);
        }
        catch (error) {
            if (onError) {
                await onError(error);
                reply.code(204);
            }
            else
                throw error;
        }
        reply.send();
    });
};
exports.pubSubFastifyPlugin = fastify_plugin_1.default(pubSubFastifyPluginAsync, '3.x');
//# sourceMappingURL=fastify-plugin.js.map